@@ -24,6 +24,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
+#include <upower.h>
 
 #include "xfpm-enum-glib.h"
 
@@ -56,11 +57,10 @@ GType        		    xfpm_battery_get_type        (void) G_GNUC_CONST;
 GtkStatusIcon              *xfpm_battery_new             (void);
 
 void			    xfpm_battery_monitor_device  (XfpmBattery *battery,
-							  DBusGProxy *proxy,
-							  DBusGProxy *proxy_prop,
-							  XfpmDeviceType device_type);
+							  const char *object_path,
+							  UpDeviceKind device_type);
 
-XfpmDeviceType	   	    xfpm_battery_get_device_type (XfpmBattery *battery);
+UpDeviceKind		    xfpm_battery_get_device_type (XfpmBattery *battery);
 
 XfpmBatteryCharge	    xfpm_battery_get_charge      (XfpmBattery *battery);
 
